@@ -29,11 +29,11 @@
 #include "goal.h"
 #include "country.h"
 #include "KMessageParts.h"
-#include "Dialogs/newGameDialogImpl.h"
-#include "Dialogs/kplayersetupdialog.h"
+#include "newgamesetup.h"
 #include "krightdialog.h"
 #include "Dialogs/joingame.h"
 #include "Jabber/kmessagejabber.h"
+#include "newplayerdata.h"
 
 #include <QLayout>
 #include <QSpinBox>
@@ -48,16 +48,16 @@
 #include <klineedit.h>
 #include <kmessagebox.h>
 #include <kvbox.h>
-#include <kgame/kmessageclient.h>
-#include <kgame/kmessageserver.h>
-#include <kgame/kgamechat.h>
 
-#include <sstream>
-#include <iostream>
+#define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
+#include <libkdegamesprivate/kgame/kmessageclient.h>
+#include <libkdegamesprivate/kgame/kmessageserver.h>
+#include <libkdegamesprivate/kgame/kgamechat.h>
 
 #include <errno.h>
 #include <sys/types.h>
 #include <signal.h>
+#include <qcache.h>
 
 namespace Ksirk{
 namespace GameLogic {
@@ -145,6 +145,7 @@ const char* GameAutomaton::KsirkMessagesIdsNames[] = {
 "AttackAuto", // 313
 "DisplayRecycleDetails", // 314
 "CurrentPlayerPlayed", // 315
+"NewGameSetupMsg", // 316
 };
 
 #define KSIRK_DEFAULT_PORT 20000
@@ -175,23 +176,23 @@ GameAutomaton::GameAutomaton() :
   
   // Connect the most important slot which tells us which properties are
   // changed
-  connect(this,SIGNAL(signalPropertyChanged(KGamePropertyBase *,KGame *)),
-          this,SLOT(slotPropertyChanged(KGamePropertyBase *,KGame *)));
+  connect(this,SIGNAL(signalPropertyChanged(KGamePropertyBase*,KGame*)),
+          this,SLOT(slotPropertyChanged(KGamePropertyBase*,KGame*)));
   
   connect(this,SIGNAL(signalPlayerJoinedGame(KPlayer*)),
           this,SLOT(slotPlayerJoinedGame(KPlayer*)));
   
-  connect(this,SIGNAL(signalNetworkData(int, const QByteArray&, quint32, quint32)),
-          this,SLOT(slotNetworkData(int, const QByteArray&, quint32, quint32)));
+  connect(this,SIGNAL(signalNetworkData(int,QByteArray,quint32,quint32)),
+          this,SLOT(slotNetworkData(int,QByteArray,quint32,quint32)));
   
-  connect(this,SIGNAL(signalClientJoinedGame(quint32, KGame*)),
-          this,SLOT(slotClientJoinedGame(quint32, KGame*)));
+  connect(this,SIGNAL(signalClientJoinedGame(quint32,KGame*)),
+          this,SLOT(slotClientJoinedGame(quint32,KGame*)));
   
   connect(messageClient(),SIGNAL(connectionBroken()),
           this,SLOT(slotConnectionToServerBroken()));
   
-  connect(messageServer(),SIGNAL(connectionLost(KMessageIO *)),
-          this,SLOT(slotConnectionToClientBroken(KMessageIO *)));
+  connect(messageServer(),SIGNAL(connectionLost(KMessageIO*)),
+          this,SLOT(slotConnectionToClientBroken(KMessageIO*)));
 
   setPolicy(KGame::PolicyDirty,true);
   
@@ -201,10 +202,7 @@ GameAutomaton::GameAutomaton() :
 GameAutomaton::~GameAutomaton()
 {
   kDebug();
-  foreach (Goal* goal, m_goals)
-  {
-    delete goal;
-  }
+  qDeleteAll(m_goals);
 }
 
 void GameAutomaton::init(KGameWindow* gw)
@@ -244,7 +242,7 @@ Player* GameAutomaton::getAnyLocalPlayer()
 
 GameAutomaton::GameState GameAutomaton::run()
 {
-//   kDebug() << "(KGame running=" <<  (gameStatus()==KGame::Run) << ")" << endl;
+//   kDebug() << "(KGame running=" <<  (gameStatus()==KGame::Run) << ")";
   if (m_game == 0 || gameStatus() == KGame::Pause)
   {
     QTimer::singleShot(200, this, SLOT(run()));
@@ -263,10 +261,10 @@ GameAutomaton::GameState GameAutomaton::run()
     m_events.pop_front();
   }
 
-//   kDebug() << "Handling " << stateName() << " ; " << event << " ; " << point << endl;
+//   kDebug() << "Handling " << stateName() << " ; " << event << " ; " << point;
 //   if (currentPlayer())
 //   {
-//     kDebug() << "current player=" << currentPlayer()->name() << " is active=" << currentPlayer()->isActive() << endl;
+//     kDebug() << "current player=" << currentPlayer()->name() << " is active=" << currentPlayer()->isActive();
 //   }
   if (event == "requestForAck")
   {
@@ -337,23 +335,7 @@ GameAutomaton::GameState GameAutomaton::run()
     }
     break;
   case ATTACK:
-    /*if  (event == "actionLButtonDown") 
-    {
-      if  ( m_game->attacker(point) )*/ 
         state(ATTACK2);
-      /*else
-        state(WAIT);
-    }
-    else if (event == "actionCancel")
-    {
-      m_game-> cancelAction();
-      state(WAIT);
-    }
-    else
-    {
-//        if (!event.isEmpty())
-//          kDebug() << "Unhandled event " << event << " during handling of " << stateName() << endl;
-    }*/
     break;
   case ATTACK2:
     kDebug() << "Handling ATTACK2";
@@ -551,7 +533,7 @@ GameAutomaton::GameState GameAutomaton::run()
     { 
       QByteArray buffer;
       QDataStream stream(&buffer, QIODevice::WriteOnly);
-      stream << quint32(WAIT_RECYCLING);
+      stream << quint32(WAIT);
       sendMessage(buffer,NextPlayerRecycling);
     }
 //     else
@@ -588,7 +570,7 @@ GameAutomaton::GameState GameAutomaton::run()
     else
     {
       //        if (!event.isEmpty())
-//          std::cerr << "Unhandled event " << event << " during handling of " << stateName() << std::endl;
+//          kError() << "Unhandled event " << event << " during handling of " << stateName();
     }
   break;
   case SHIFT2:
@@ -649,33 +631,11 @@ GameAutomaton::GameState GameAutomaton::run()
     }
     else
     {
-      //std::cerr << "Unhandled event " << event << " during handling of " << stateName() << std::endl;
+      //kError() << "Unhandled event " << event << " during handling of " << stateName();
     }
   break;
   case WAIT_RECYCLING:
-//     kDebug() << "event = '" << event << "'" << endl;
-    /*if  (event == "actionLButtonDown") 
-    {
-      QByteArray buffer;
-      QDataStream stream(&buffer, QIODevice::WriteOnly);
-      stream << point << quint32(true);
-      sendMessage(buffer,PlayerPutsArmy);
-    }
-    else if (event == "actionRButtonDown") 
-    {
-      QByteArray buffer;
-      QDataStream stream(&buffer, QIODevice::WriteOnly);
-      stream << point;
-      sendMessage(buffer,PlayerRemovesArmy);
-    }
-    else if (event == "actionNextPlayer")
-    {
-      QByteArray buffer;
-      QDataStream stream(&buffer, QIODevice::WriteOnly);
-      stream << -1;
-      sendMessage(buffer,NextPlayerRecycling);
-    }
-    else*/ if (event == "actionRecycling") 
+    if (event == "actionRecycling")
     {
       QByteArray buffer;
       sendMessage(buffer,ActionRecycling);
@@ -771,7 +731,7 @@ GameAutomaton::GameState GameAutomaton::run()
     else
     {
       //        if (!event.isEmpty())
-//          std::cerr << "Unhandled event " << event << " during handling of " << stateName() << std::endl;
+//          kError() << "Unhandled event " << event << " during handling of " << stateName();
     }
     // other case : state doesn't change
     break;
@@ -804,7 +764,7 @@ GameAutomaton::GameState GameAutomaton::run()
       QDataStream stream(&buffer, QIODevice::WriteOnly);
       stream << quint32(1);
       sendMessage(buffer,Invade);
-      state(WAIT);
+//       state(WAIT);
     }
     else if (event == "actionInvade5")
     {
@@ -814,7 +774,7 @@ GameAutomaton::GameState GameAutomaton::run()
       QDataStream stream(&buffer, QIODevice::WriteOnly);
       stream << quint32(5);
       sendMessage(buffer,Invade);
-      state(WAIT);
+//       state(WAIT);
     }
     else if (event == "actionInvade10")
     {
@@ -824,7 +784,7 @@ GameAutomaton::GameState GameAutomaton::run()
       QDataStream stream(&buffer, QIODevice::WriteOnly);
       stream << quint32(10);
       sendMessage(buffer,Invade);
-      state(WAIT);
+//       state(WAIT);
     }
     else if (event == "actionInvasionFinished")
     {
@@ -834,12 +794,12 @@ GameAutomaton::GameState GameAutomaton::run()
     else if (event == "actionLButtonUp")
     {
       kDebug() << "actionLButtonUp in WAIT1";
-      m_game->secondCountryAt(point);
       
       if (!currentPlayer()-> isAI())
       {
         if (m_game->isMoveValid(point) && m_game->firstCountry()->nbArmies() !=1)
         {
+          m_game->secondCountryAt(point);
           state(WAIT);
           kDebug() << "Sending MoveSlide";
           QByteArray buffer;
@@ -849,6 +809,7 @@ GameAutomaton::GameState GameAutomaton::run()
         else if (m_game->isFightValid(point)
                 && m_game->firstCountry()->nbArmies() != 1)
         {
+          m_game->secondCountryAt(point);
           if (m_game->firstCountry()->nbArmies() > 3)
           {
             m_game->frame()->getAttack1Action()->setVisible(true);
@@ -877,6 +838,10 @@ GameAutomaton::GameState GameAutomaton::run()
           state(WAIT);
         }
       }
+      else
+      {
+        m_game->secondCountryAt(point);
+      }
     }
     else if (event == "actionLButtonDown")
     {
@@ -940,12 +905,13 @@ void GameAutomaton::gameEvent(const QString& event, const QPointF& point)
 /** returns the name of the current state */
 QString GameAutomaton::stateName() const
 {
-  if (m_state >= sizeof(GameStateNames))
+  if (m_state >= (int) sizeof(GameStateNames))
   {
-    ::std::ostringstream oss;
+    QString string;
+    QTextStream oss(&string);
     oss << "Invalid stored state id: " << m_state;
-    kError() << oss.str().c_str() << endl;
-    return QString::fromUtf8(oss.str().c_str());
+    kError() << string << endl;
+    return string;
   }
   else
   {
@@ -953,9 +919,9 @@ QString GameAutomaton::stateName() const
   }
 }
 
-void GameAutomaton::saveXml(::std::ostream& xmlStream)
+void GameAutomaton::saveXml(QTextStream& xmlStream)
 {
-    xmlStream << "<gameautomaton state=\"" << GameStateNames[m_state] << "\" />" << ::std::endl;
+    xmlStream << "<gameautomaton state=\"" << GameStateNames[m_state] << "\" />" << endl;
 }
 
 const QString& GameAutomaton::skin() const
@@ -1077,9 +1043,9 @@ void GameAutomaton::createIO(KPlayer *player,KGameIO::IOMode io)
     // Connect mouse input to a function to process the actual input
     connect(
       input,
-      SIGNAL(signalMouseEvent(KGameIO *,QDataStream &,QMouseEvent *,bool *)),
+      SIGNAL(signalMouseEvent(KGameIO*,QDataStream&,QMouseEvent*,bool*)),
       m_game->frame(),
-      SLOT(slotMouseInput(KGameIO *,QDataStream &,QMouseEvent *,bool *)));
+      SLOT(slotMouseInput(KGameIO*,QDataStream&,QMouseEvent*,bool*)));
 
     // Add the device to the player
     player->addGameIO(input);
@@ -1147,48 +1113,21 @@ bool GameAutomaton::setupPlayersNumberAndSkin(NetworkGameType netGameType)
   return false;
 }
 
-bool GameAutomaton::finishSetupPlayersNumberAndSkin(const QString& skin, NetworkGameType networkGame, uint newPlayersNumber)
+bool GameAutomaton::finishSetupPlayersNumberAndSkin()
 {
-  kDebug() << skin << networkGame << newPlayersNumber;
+  kDebug();
+  
+  setUseGoals(m_game->newGameSetup()->useGoals());
+  state(GameLogic::GameAutomaton::INIT);
+  savedState(GameLogic::GameAutomaton::INVALID);
+  setNetworkPlayersNumber(m_game->newGameSetup()->nbNetworkPlayers());
   m_startingGame = true;
   state(INIT);
-  setMinPlayers(newPlayersNumber);
-  setMaxPlayers(newPlayersNumber);
-  m_nbPlayers = newPlayersNumber;
-//   kDebug() << "min and max players number set to " << newPlayersNumber << endl;
+  setMinPlayers(m_game->newGameSetup()->nbPlayers());
+  setMaxPlayers(m_game->newGameSetup()->nbPlayers());
+  m_nbPlayers = m_game->newGameSetup()->nbPlayers();
   
-//   kDebug() << "Got skin name: " << skinName << endl;
-/*  if (skinName != m_skin)
-  {*/
-  kDebug() << "Changing skin" << endl;
-  m_skin = skin;
-//   }
-  
-  if (m_netGameType == Socket)
-  {
-// porting    
-    KDialog* dialog = new KDialog( m_game );
-    dialog->setCaption( i18n("Port configuration") );
-    dialog->setButtons( KDialog::Ok );
-
-    QGroupBox* mRemoteGroup=new QGroupBox(i18n("TCP port on which to offer connections"), dialog);
-    QSpinBox* spinBox = new QSpinBox(0);
-    spinBox->setMinimum(1);
-    spinBox->setMaximum(32731);
-    spinBox->setValue(m_port);
-    QVBoxLayout *vbox = new QVBoxLayout;
-    vbox->addWidget(spinBox);
-    vbox->addStretch(1);
-    mRemoteGroup->setLayout(vbox);
-
-    dialog->setMainWidget(mRemoteGroup);
-    dialog->exec();
-    
-    m_port = spinBox->value();
-    offerConnections(m_port);
-    dialog->hide();
-  }
-  return m_game->finishSetupPlayers();
+  return true;
 }
 
 void GameAutomaton::setGoalFor(Player* player)
@@ -1249,48 +1188,35 @@ bool GameAutomaton::joinNetworkGame()
 {
   kDebug();
    if (stateName() == "INIT"
-     || (KMessageBox::warningContinueCancel(m_game,i18n("Do you really want to end your current game and join another ?"),i18n("New game confirmation"),KStandardGuiItem::yes()) == KMessageBox::Continue))
+     || (KMessageBox::warningContinueCancel(m_game,i18n("Do you really want to end your current game and join another?"),i18n( "New game confirmation" ),KStandardGuiItem::yes()) == KMessageBox::Continue))
    {
-      // Set default network parameter
-      QString host = "localhost";
-      int port = KSIRK_DEFAULT_PORT;
-
-      QString nick;
-      // porting
-      JoinGameDialog* dialog = new JoinGameDialog(host, port, m_game);
-      QDialog::DialogCode valid = QDialog::DialogCode(dialog->exec());
-
-      if (valid == QDialog::Rejected)
-      {
-         return false;
-      }
-
-      // stop game
-      setGameStatus(KGame::End);
-      state(INIT);
-      savedState(INVALID);
-
-      host = dialog->hostEdit->text();
-      port = dialog->portEdit->text().toInt();
-
-      if (messageServer() != 0)
-      {
-        QObject::disconnect(messageServer(),SIGNAL(connectionLost(KMessageIO *)),
-                             this,SLOT(slotConnectionToClientBroken(KMessageIO *)));
-      }
-      kDebug() << "Before connectToServer" << endl;
-      bool status = connectToServer(host, port);
-      kDebug() << "After connectToServer" << endl;
-      connect(messageServer(),SIGNAL(connectionLost(KMessageIO *)),
-               this,SLOT(slotConnectionToClientBroken(KMessageIO *)));
-               return status;
+      m_game->joinNetworkGame();
    }
    return false;
 }
 
+bool GameAutomaton::connectToServ()
+{
+  kDebug();
+  if (messageServer() != 0)
+  {
+    QObject::disconnect(messageServer(),SIGNAL(connectionLost(KMessageIO*)),
+                        this,SLOT(slotConnectionToClientBroken(KMessageIO*)));
+  }
+  kDebug() << "Before connectToServer" << endl;
+  QString host = m_game->newGameSetup()->host();
+  int port = m_game->newGameSetup()->tcpPort();
+  bool status = connectToServer(host, port);
+  kDebug() << "After connectToServer" << status;
+  if (messageServer())
+    connect(messageServer(),SIGNAL(connectionLost(KMessageIO*)),
+          this,SLOT(slotConnectionToClientBroken(KMessageIO*)));
+  return status;
+}
+
 bool GameAutomaton::joinJabberGame(const QString& nick)
 {
-  if (stateName() == "INIT" || (KMessageBox::warningContinueCancel(m_game,i18n("Do you really want to end your current game and join another ?"),i18n("New game confirmation"),KStandardGuiItem::yes()) == KMessageBox::Continue))
+  if (stateName() == "INIT" || (KMessageBox::warningContinueCancel(m_game,i18n("Do you really want to end your current game and join another?"),i18n( "New game confirmation" ),KStandardGuiItem::yes()) == KMessageBox::Continue))
   {
     // stop game
     setGameStatus(KGame::End);
@@ -1299,8 +1225,8 @@ bool GameAutomaton::joinJabberGame(const QString& nick)
     
     if (messageServer() != 0)
     {
-      QObject::disconnect(messageServer(),SIGNAL(connectionLost(KMessageIO *)),
-                           this,SLOT(slotConnectionToClientBroken(KMessageIO *)));
+      QObject::disconnect(messageServer(),SIGNAL(connectionLost(KMessageIO*)),
+                           this,SLOT(slotConnectionToClientBroken(KMessageIO*)));
     }
     
     kDebug() << "Before connectToServer" << endl;
@@ -1308,7 +1234,7 @@ bool GameAutomaton::joinJabberGame(const QString& nick)
     KMessageJabber* messageIO = new KMessageJabber(m_game->serverJid().full(), m_game->jabberClient(), this);
     bool status = connectToServer(messageIO);
     //       bool status = connectToServer(host, port);
-    kDebug() << "After connectToServer" << status << endl;
+    kDebug() << "After connectToServer" << status;
     if (status)
     {
       QByteArray msg("connect");
@@ -1318,8 +1244,8 @@ bool GameAutomaton::joinJabberGame(const QString& nick)
       message.setBody(msg);
       m_game->jabberClient()->sendMessage(message);
     }
-    //       connect(messageServer(),SIGNAL(connectionLost(KMessageIO *)),
-                                                           //          this,SLOT(slotConnectionToClientBroken(KMessageIO *)));
+    //       connect(messageServer(),SIGNAL(connectionLost(KMessageIO*)),
+                                                           //          this,SLOT(slotConnectionToClientBroken(KMessageIO*)));
                                                            return status;
   }
   return false;
@@ -1427,7 +1353,7 @@ void GameAutomaton::currentPlayer(Player* player)
 
 void GameAutomaton::slotPlayerJoinedGame(KPlayer* player)
 {
-  kDebug() << "slotPlayerJoinedGame currently " << playerList()->count() << " / " << maxPlayers() << endl;
+  kDebug() << "currently " << playerList()->count() << " / " << maxPlayers() << endl;
   Player* p = dynamic_cast<Player*>(player);
   Q_ASSERT(p);
   
@@ -1479,6 +1405,20 @@ void GameAutomaton::slotPlayerJoinedGame(KPlayer* player)
     kDebug() << "Sending StartGame" << endl;
     sendMessage(buffer,StartGame);
   }
+  else
+  {
+    if (!player->isVirtual())
+    {
+      m_game->showNewGameSummary();
+    }
+    m_game->newGameSetup()->setNbPlayers(maxPlayers());
+  }
+  NewPlayerData* pd = new NewPlayerData(p->name(),p->getNation()->name(),"",p->isAI(),true);
+  if (!m_game->newGameSetup()->addPlayer(pd))
+  {
+    delete pd;
+  }
+  m_game->updateNewGameSummary();
 }
 
 bool GameAutomaton::startGame()
@@ -1540,7 +1480,7 @@ bool GameAutomaton::startGame()
 
 void GameAutomaton::changePlayerName(Player* player)
 {
-//   kDebug() << endl;
+//   kDebug();
   
   QMap< QString, QString > nations = m_game->nationsList();
   PlayersArray::iterator it = playerList()->begin();
@@ -1560,20 +1500,16 @@ void GameAutomaton::changePlayerName(Player* player)
   QString nationName;
   
   QString nomEntre = player->name();
-  bool computer = player->isAI();
   
   bool found = true;
-  KMessageBox::information(m_game, i18n("Please choose another name"), i18n("KsirK - Name already used !"));
+  KMessageBox::information(m_game, i18n("Please choose another name"), i18n("KsirK - Name already used!"));
   while(found)
   {
     bool emptyName = true;
     while (emptyName)
     {
-      mes = i18n("Player number %1, what's your name ?", 1);
-      bool network = false;
+      mes = i18n("Player number %1, what's your name?", 1);
       QString password;
-      KPlayerSetupDialog(this, m_game->theWorld(), 1, nomEntre, network, password, computer, nations, nationName, m_game).exec();
-//     kDebug() << "After KPlayerSetupDialog. name: " << nomEntre << endl;
       if (nomEntre.isEmpty())
       {
         mes = i18n("Error - Player %1, you have to choose a name.", 1);
@@ -1629,11 +1565,8 @@ void GameAutomaton::changePlayerNation(Player* player)
   QString nationName;
   
   QString nomEntre = player->name();
-  bool computer = player->isAI();
-  KMessageBox::information(m_game, i18n("Please choose another nation"), i18n("KsirK - Nation already used !"));
-  bool network = false;
-  QString password = false;
-  KPlayerSetupDialog(this, m_game->theWorld(), 1, nomEntre, network, password, computer, nations, nationName, m_game).exec();
+  KMessageBox::information(m_game, i18n("Please choose another nation"), i18n("KsirK - Nation already used!"));
+  QString password;
   QByteArray buffer;
   QDataStream stream(&buffer, QIODevice::WriteOnly);
   stream << player->name() << nationName;
@@ -1683,7 +1616,7 @@ void GameAutomaton::slotPropertyChanged(KGamePropertyBase *prop,KGame *)
 
 void GameAutomaton::slotClientJoinedGame(quint32 clientid, KGame* /*me*/)
 {
-  kDebug() << clientid << endl;
+  kDebug() << clientid;
   if (isAdmin() && clientid!=gameId())
   {
     QByteArray buffernbp;
@@ -1691,6 +1624,11 @@ void GameAutomaton::slotClientJoinedGame(quint32 clientid, KGame* /*me*/)
     streamnbp << m_nbPlayers;
     sendMessage(buffernbp,NbPlayers,clientid);
     
+    QByteArray bufferngs;
+    QDataStream streamngs(&bufferngs, QIODevice::WriteOnly);
+    streamngs << *m_game->newGameSetup();
+    sendMessage(bufferngs,NewGameSetupMsg,clientid);
+    
     QByteArray buffer;
     QDataStream stream(&buffer, QIODevice::WriteOnly);
     if (m_game->waitedPlayers().empty())
@@ -1713,31 +1651,29 @@ void GameAutomaton::slotClientJoinedGame(quint32 clientid, KGame* /*me*/)
 
 void GameAutomaton::slotConnectionToServerBroken()
 {
-  kDebug() << endl;
+  kDebug();
 
 //   m_game->haltTimer();
   if (m_state != GAME_OVER)
   {
-    if (KMessageBox::questionYesNoCancel(m_game,
-        i18n("KsirK - Lost connection to server !\nWhat do you want to do ?"),
-        i18n("Starting a new game or exit."), 
-        KGuiItem(i18n("New Game")),
-        KGuiItem(i18n("Exit")),
-        KGuiItem(i18n("Do nothing")))
-            == KMessageBox::Yes)
+    int answer = KMessageBox::questionYesNoCancel(m_game,
+                                                  i18n("KsirK - Lost connection to server!\nWhat do you want to do?"),
+                                                  i18n("Starting a new game or exit."),
+                                                  KGuiItem(i18n("New Game")),
+                                                  KGuiItem(i18n("Exit")),
+                                                  KGuiItem(i18n("Do nothing")));
+    if (answer == KMessageBox::Yes)
     {
-      if (!m_game->actionNewGame(GameAutomaton::None))
-        exit(0);
+      m_game->showMainMenu();
     }
-    else
+    else if (answer == KMessageBox::No)
     {
       exit(0);
     }
+    else
+    {
+    }
   }
-//   else
-//   {
-//     m_game->haltTimer();
-//   }
 }
   
 void GameAutomaton::slotConnectionToClientBroken(KMessageIO *)
@@ -1748,7 +1684,7 @@ void GameAutomaton::slotConnectionToClientBroken(KMessageIO *)
   {
     KMessageBox::information(m_game, 
                             i18n("Lost connection to a client.\nFor the moment, you can only save the game and start a new one or quit.\nThis will be improved in a future version."), 
-                            i18n("KsirK - Lost connection to client !"));
+                            i18n("KsirK - Lost connection to client!"));
     switch ( KMessageBox::warningYesNo( m_game, i18n("Do want to save your game?")) ) 
     {
     case KMessageBox::Yes :
@@ -1780,6 +1716,7 @@ void GameAutomaton::finalizePlayers()
   {
     sendMessage(buffer,DisplayGoals);
   }
+  m_game->showMap();
   m_startingGame = false;
 }
 
@@ -1911,7 +1848,7 @@ void GameAutomaton::countriesDistribution()
   KMessageParts messageParts;
   messageParts
     << pm
-    << I18N_NOOP("%1 : %2 armies to place")
+    << I18N_NOOP("%1: %2 armies to place")
     << nextPlayerName
     <<  QString::number( initialNbArmies - distributedCountriesNumberMap[nextPlayerName]);
   kDebug() << "Message parts size= " << messageParts.size() << endl;
@@ -1950,6 +1887,7 @@ void GameAutomaton::movingArmyArrived(Country* country, unsigned int number)
   kDebug() << number << endl;
   country->incrNbArmies(number);
   country->createArmiesSprites();
+  checkGoal(country->owner());
 }
 
 void GameAutomaton::firingFinished()
@@ -1993,7 +1931,7 @@ void GameAutomaton::displayGoals()
       KMessageBox::information(
           game(),
           i18n("%1, your goal will be displayed. Please<br>"
-               "make sure that no other player can see it !",(*it)->name()),
+               "make sure that no other player can see it!",(*it)->name()),
           i18n("KsirK - Displaying Goal"));
       dynamic_cast<Player*>(*it)->goal().show();
     }
@@ -2005,7 +1943,7 @@ void GameAutomaton::moveSlide()
 {
   kDebug();
   if (!currentPlayer()->isVirtual())
-    m_game->slideInvade(m_game->firstCountry(), m_game->secondCountry(),KGameWindow::Moving);
+    m_game->slideInvade(m_game->firstCountry(), m_game->secondCountry(),InvasionSlider::Moving);
 }
 
 /**
@@ -2066,6 +2004,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
   quint32 attackAutoValue;
   quint32 availArmies;
   quint32 elemType;
+  quint32 nb;
   
   if (currentPlayer() != 0 && currentPlayer()->getFlag() != 0)
   {
@@ -2078,7 +2017,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
   {
   case CountryOwner:
     stream >> countryName >> playerName;
-//     kDebug() << "CountryOwner for " << m_game->theWorld()->countryNamed(countryName) << " " << countryName << " and " << playerName << endl;
+    kDebug() << "CountryOwner for " << (void*)m_game->theWorld()->countryNamed(countryName) << " " << countryName << " and " << (void*)playerNamed(playerName) << playerName << endl;
     m_game->theWorld()->countryNamed(countryName)-> owner(playerNamed(playerName));
     break;
   case PlayerPutsInitialArmy:
@@ -2267,8 +2206,26 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
     break;
   case Invade:
     stream >> nbArmies;
-    if (m_game-> invade(nbArmies))
-      m_game-> incrNbMovedArmies(nbArmies);
+    nb = nbArmies;
+    while (nb >= 10)
+    {
+      if (m_game-> invade(10))
+        m_game-> incrNbMovedArmies(10);
+      nb -= 10;
+    }
+    while (nb >= 5)
+    {
+      if (m_game-> invade(5))
+        m_game-> incrNbMovedArmies(5);
+      nb -= 5;
+    }
+    while (nb > 0)
+    {
+      if (m_game-> invade(1))
+        m_game-> incrNbMovedArmies(1);
+      nb--;
+    }
+    
     break;
   case Retreat:
     stream >> nbArmies;
@@ -2306,7 +2263,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
     }
     break;
   case ShowArmiesToPlace:
-    messageParts << pm << I18N_NOOP("%1 : %2 armies to place") << (currentPlayer()-> name()) 
+    messageParts << pm << I18N_NOOP("%1: %2 armies to place") << (currentPlayer()-> name()) 
       << QString::number(currentPlayer()-> getNbAvailArmies());
     m_game->broadcastChangeItem(messageParts, ID_STATUS_MSG2);
     m_game->showMessage(i18n("Now, place your armies in your countries<br>by clicking in the target countries."));
@@ -2319,7 +2276,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
     if (isAdmin())
     {
 //       stream >> playerName;
-      messageParts << I18N_NOOP("%1 choose to end recycling ; there is now %2 players who want so");
+      messageParts << I18N_NOOP("%1 choose to end recycling; there are now %2 players who want so");
       stream >> nbVotes;
       stream >> playerId;
       playersNames = ((Player*)(findPlayer(playerId)))->name();
@@ -2409,7 +2366,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
     {
       if (explosing != 0 && explosing != 1 && explosing != 2)
       {
-        KMessageBox::information(m_game, i18n("Problem : no one destroyed"), i18n("Ksirk - Error !"));
+        KMessageBox::information(m_game, i18n("Problem : no one destroyed"), i18n("Ksirk - Error!"));
       }
       else
       {
@@ -2458,7 +2415,7 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
   case InvalidPassword:
     if (receiver == gameId())
     {
-      KMessageBox::information(m_game, i18n("You entered an invalid password.\nPlease try again."), i18n("KsirK - Invalid password !"));
+      KMessageBox::information(m_game, i18n("You entered an invalid password.\nPlease try again."), i18n("KsirK - Invalid password!"));
       m_game->setupOneWaitedPlayer();
     }
     break;
@@ -2483,20 +2440,20 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
   case CheckGoal:
     if (isAdmin())
     {
-//       kDebug() << "CheckGoal: " << endl;
+      kDebug() << "CheckGoal: " << endl;
       stream >> playerId;
       player = dynamic_cast< Player* >(findPlayer(playerId));
       if (player)
       {
         if (player->checkGoal())
         {
-//           kDebug() << "    goal reached for " << player->name() << endl;
-//           kDebug() << "    setting state to " << GameStateNames[GAME_OVER] << endl;
+          kDebug() << "    goal reached for " << player->name() << endl;
+          kDebug() << "    setting state to " << GameStateNames[GAME_OVER] << endl;
 //           m_game->haltTimer();
           setGameStatus(KGame::End);
           state(GAME_OVER);
           sendStream << player->id();
-//           kDebug() << "    sending Winner" << endl;
+          kDebug() << "    sending Winner" << endl;
           sendMessage(sendBuffer,Winner);
         }
       }
@@ -2525,8 +2482,8 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
       finalizePlayers();
     break;
   case Winner:
-    QObject::disconnect(messageServer(),SIGNAL(connectionLost(KMessageIO *)),
-                        this,SLOT(slotConnectionToClientBroken(KMessageIO *)));
+    QObject::disconnect(messageServer(),SIGNAL(connectionLost(KMessageIO*)),
+                        this,SLOT(slotConnectionToClientBroken(KMessageIO*)));
     stream >> playerId;
     m_game->winner(dynamic_cast<Player*>(findPlayer(playerId)));
     break;
@@ -2590,6 +2547,10 @@ void GameAutomaton::slotNetworkData(int msgid, const QByteArray &buffer, quint32
   case ResetPlayersDistributionData:
     resetPlayersDistributionData();
     break;
+  case NewGameSetupMsg:
+    kDebug() << "Got message NewGameSetupMsg";
+    stream >> *m_game->newGameSetup();
+    break;
   default: ;
   }
 }
@@ -2660,14 +2621,14 @@ void GameAutomaton::actionNextPlayer()
     || currentPlayer()->isAI()
     || m_currentPlayerPlayed
     || (KMessageBox::questionYesNo (m_game,
-                                     i18n("%1, you have not played anything this turn.\nDo you really want to lose your turn ?",m_currentPlayer),
-                                     i18n("Really Next Player ?")) == KMessageBox::Yes) )
+                                     i18n("%1, you have not played anything this turn.\nDo you really want to lose your turn?",m_currentPlayer),
+                                     i18n("Really Next Player?")) == KMessageBox::Yes) )
   {
     QByteArray buffer;
     QDataStream stream(&buffer, QIODevice::WriteOnly);
     stream << currentPlayer()->name();
     stream << (quint32)NEWARMIES;
-    kDebug() << "sending NextPlayerNormal" << currentPlayer()->name() << NEWARMIES;
+    kDebug() << "(state " << stateName() << ") sending NextPlayerNormal" << currentPlayer()->name() << NEWARMIES;
     sendMessage(buffer,NextPlayerNormal);
     m_game-> cancelAction();
   }
@@ -2677,13 +2638,38 @@ void GameAutomaton::removeAllPlayers()
 {
   kDebug();
   m_currentPlayer = "";
-  foreach (KPlayer*p, *playerList())
-  {
-    delete p;
-  }
+  qDeleteAll(*playerList());
   playerList()->clear();
 }
 
+void GameAutomaton::newGameNext()
+{
+  kDebug();
+  m_startingGame = true;
+  state(INIT);
+  
+  kDebug() << "Changing skin";
+  m_skin = m_game->newGameSetup()->skin();
+  if (m_game->newGameSetup()->networkGameType() == Socket)
+  {
+    offerConnections(m_game->newGameSetup()->tcpPort());
+  }
+  m_game->finishSetupPlayers();
+}
+
+void GameAutomaton::checkGoal(Player* player) 
+{
+  QByteArray buffer;
+  QDataStream stream(&buffer, QIODevice::WriteOnly);
+  if (player == 0)
+    stream << currentPlayer()->id();
+  else
+    stream << player->id();
+  kDebug() << "sending CheckGoal";
+  sendMessage(buffer,CheckGoal);
+}
+
+
 } // closing namespace GameLogic
 } // closing namespace Ksirk
 
